document.addEventListener('DOMContentLoaded', () => {
  const generateBtn = document.getElementById('generate-btn');
  const elementsContainer = document.getElementById('elements-container');
  
  generateBtn.addEventListener('click', generateStoryElements);

  function generateStoryElements() {
    const storyIdea = document.getElementById('story-idea').value;
    if (!storyIdea.trim()) {
      alert('Please enter a story idea first!');
      return;
    }

    elementsContainer.classList.remove('hidden');
    
    // Clear previous elements
    document.querySelectorAll('.grid-container').forEach(container => {
      container.innerHTML = '';
    });

    // Generate and display elements for each category
    generateWorldBuilding();
    generateCharacters();
    generatePlotElements();
    generateTechnology();
  }

  function createCard(title, description) {
    const card = document.createElement('div');
    card.className = 'story-card';
    card.innerHTML = `
      <h4>${title}</h4>
      <p>${description}</p>
    `;
    return card;
  }

  function generateWorldBuilding() {
    const container = document.querySelector('#world-building .grid-container');
    const elements = [
      { title: 'Setting', description: 'Define the primary location and time period' },
      { title: 'Social Structure', description: 'Develop the societal organization and hierarchy' },
      { title: 'History', description: 'Create the background events that shaped this world' },
      { title: 'Environment', description: 'Describe the physical characteristics and challenges' }
    ];
    
    elements.forEach(element => {
      container.appendChild(createCard(element.title, element.description));
    });
  }

  function generateCharacters() {
    const container = document.querySelector('#characters .grid-container');
    const elements = [
      { title: 'Protagonist', description: 'Define your main character\'s goals and motivations' },
      { title: 'Antagonist', description: 'Create the opposing force or character' },
      { title: 'Supporting Cast', description: 'Develop key secondary characters' },
      { title: 'Character Relationships', description: 'Map out character interactions and dynamics' }
    ];
    
    elements.forEach(element => {
      container.appendChild(createCard(element.title, element.description));
    });
  }

  function generatePlotElements() {
    const container = document.querySelector('#plot .grid-container');
    const elements = [
      { title: 'Main Conflict', description: 'Define the central problem or challenge' },
      { title: 'Plot Points', description: 'Outline major events and turning points' },
      { title: 'Subplots', description: 'Develop secondary storylines' },
      { title: 'Resolution', description: 'Plan how conflicts will be resolved' }
    ];
    
    elements.forEach(element => {
      container.appendChild(createCard(element.title, element.description));
    });
  }

  function generateTechnology() {
    const container = document.querySelector('#technology .grid-container');
    const elements = [
      { title: 'Core Technologies', description: 'Define key scientific advances' },
      { title: 'Scientific Principles', description: 'Establish rules for your sci-fi universe' },
      { title: 'Tech Impact', description: 'Explore how technology affects society' },
      { title: 'Limitations', description: 'Set boundaries for your technological elements' }
    ];
    
    elements.forEach(element => {
      container.appendChild(createCard(element.title, element.description));
    });
  }
});
